@@ -24,20 +24,6 @@ fn test_cd_fails() {
     .is_err());
 }
 
-#[test]
-/// ```compile_fail
-/// run_cmd!(ls || true || true).unwrap();
-/// run_cmd!(ls || true | wc).unwrap();
-/// ```
-fn test_or_cmd() {
-    assert!(run_cmd! {
-        ls /nofile || true;
-        echo "continue";
-    }
-    .is_ok());
-    assert!(run_cmd!(false || ls | wc).is_ok());
-}
-
 #[test]
 fn test_run_cmds() {
     assert!(run_cmd! {
@@ -148,17 +134,7 @@ fn test_tls_set() {
 }
 
 #[test]
-fn test_pipe_fail() {
-    assert!(run_cmd!(false | wc).is_err());
-    assert!(run_cmd!(echo xx | false | wc | wc | wc).is_err());
-}
-
-#[test]
-/// ```compile_fail
-/// run_cmd!(ls | |).unwrap();
-/// run_cmd!(ls | ||).unwrap();
-/// ```
-fn test_pipe_ok() {
+fn test_pipe() {
     use_builtin_cmd!(echo);
     assert!(run_cmd!(echo "xx").is_ok());
     assert_eq!(run_fun!(echo "xx").unwrap(), "xx");
@@ -166,6 +142,9 @@ fn test_pipe_ok() {
     assert!(run_cmd!(echo xx | wc | wc | wc | wc).is_ok());
     assert!(run_cmd!(seq 1 10000000 | head -1).is_err());
 
+    assert!(run_cmd!(false | wc).is_err());
+    assert!(run_cmd!(echo xx | false | wc | wc | wc).is_err());
+
     set_pipefail(false);
     assert!(run_cmd!(du -ah . | sort -hr | head -n 10).is_ok());
     set_pipefail(true);
@@ -184,14 +163,14 @@ fn test_redirect() {
     assert!(run_cmd!(echo xxxx > /tmp/f).is_ok());
     assert!(run_cmd!(echo yyyy >> /tmp/f).is_ok());
     assert!(run_cmd!(
-        ls /x 2>/tmp/lsx.log || true;
+        ignore ls /x 2>/tmp/lsx.log;
         echo "dump file:";
         cat /tmp/lsx.log;
         rm /tmp/lsx.log;
     )
     .is_ok());
-    assert!(run_cmd!(ls /x 2>/dev/null || true).is_ok());
-    assert!(run_cmd!(ls /x &>/tmp/f || true).is_ok());
+    assert!(run_cmd!(ignore ls /x 2>/dev/null).is_ok());
+    assert!(run_cmd!(ignore ls /x &>/tmp/f).is_ok());
     assert!(run_cmd!(wc -w < /tmp/f).is_ok());
     assert!(run_cmd!(ls 1>&1).is_ok());
     assert!(run_cmd!(ls 2>&2).is_ok());
@@ -250,9 +229,6 @@ fn test_current_dir() {
 /// run_cmd!(ls / /x &> > /tmp/f).unwrap();
 /// run_cmd!(ls / /x > > /tmp/f).unwrap();
 /// run_cmd!(ls / /x >> > /tmp/f).unwrap();
-/// run_cmd!(ls &< dirlist || true).unwrap();
-/// run_cmd!(ls & < dirlist || true).unwrap();
-/// run_cmd!(ls & dirlist || true).unwrap();
 /// ```
 fn test_redirect_fail() {}
 
